flutter_testmate library

Classes

SafeExpect
Utility functions for safe expect operations
SafeExpectResult
A wrapper that allows chaining .catch() to expect statements
TestFailureInfo
Structure to hold test failure information

Extensions

SafeExpectExtension on T
Extension to add catch functionality to expect statements

Functions

expect(dynamic actual, dynamic matcher, {String? reason, dynamic skip}) → void
Override the default expect function to automatically use SafeExpect.catchError This allows you to write: expect(actual, matcher) instead of SafeExpect.catchError(() => expect(actual, matcher))
group(String description, void body()) → void
Override the default group function to capture group names
testmateGroup(String description, void body()) → void
Custom group wrapper that captures group name (alias for group)
testmateTestWidgets(String description, WidgetTesterCallback callback) → void
Custom testWidgets wrapper that captures test name (alias for testWidgets)
testWidgets(String description, WidgetTesterCallback callback, {bool? skip, Timeout? timeout, bool semanticsEnabled = true, TestVariant<Object?> variant = const flutter_test.DefaultTestVariant(), dynamic tags}) → void
Override the default testWidgets function to capture test names